pub enum ExecutionPhase {
First,
Normal,
Last,
}Expand description
An enum to indicate the phase for plans at a given time.
Most plans will occur as Normal. Plans with phase First are
handled before all Normal plans, and those with phase Last are
handled after all Normal plans. In all cases ties between plans at the
same time and with the same phase are handled in the order of scheduling.
Variants