EntityMap

Struct EntityMap 

pub struct EntityMap<E: Entity, V> { /* private fields */ }
A Vec-backed map keyed by EntityId<E>.

Implementations

Source

impl<E: Entity, V> EntityMap<E, V>

pub fn new() -> Self

Creates an empty EntityMap.

pub fn with_capacity(capacity: usize) -> Self

Creates an empty EntityMap with space for at least capacity values.

pub fn into_entity_vec(self) -> EntityVec<E, Option<V>>

Cheap conversion to an EntityVec<E, Option<V>>

pub fn len(&self) -> usize

Returns the number of stored key-value pairs.

pub fn capacity(&self) -> usize

Returns the capacity of the backing storage.

pub fn is_empty(&self) -> bool

Returns true if the map contains no values.

pub fn reserve(&mut self, additional: usize)

Reserves capacity for at least additional more values.

pub fn shrink_to_fit(&mut self)

Shrinks the backing vector to fit the highest occupied entity ID.

pub fn contains_key(&self, entity_id: EntityId<E>) -> bool

Returns true if entity_id is present in the map.

pub fn get(&self, entity_id: EntityId<E>) -> Option<&V>

Returns the value for entity_id, or None if not present.

pub fn get_mut(&mut self, entity_id: EntityId<E>) -> Option<&mut V>

Returns the value for entity_id mutably, or None if not present.

pub fn insert(&mut self, entity_id: EntityId<E>, value: V) -> Option<V>

Inserts value for entity_id, returning the previous value if one existed.

pub fn get_or_insert(&mut self, entity_id: EntityId<E>, value: V) -> &mut V

Returns the value for entity_id, inserting value if it is not already present.

pub fn get_or_insert_with<F>(&mut self, entity_id: EntityId<E>, f: F) -> &mut V
where F: FnOnce() -> V,

Returns the value for entity_id, inserting a value from f if it is not already present.

pub fn remove(&mut self, entity_id: EntityId<E>) -> Option<V>

Removes and returns the value for entity_id, if present.

pub fn clear(&mut self)

Clears the map, removing all key-value pairs.

pub fn iter(&self) -> Iter<'_, E, V>

Returns an iterator over (EntityId<E>, &V) pairs.