ValueVec

Struct ValueVec 

pub struct ValueVec<V: Copy> { /* private fields */ }
A by-value, ref-less vector with interior mutability. Values of type V can be moved into and out of the vector. We require V to be Copy to avoid subtle soundness issues.

Implementations

Source

impl<V: Copy> ValueVec<V>

pub fn new() -> Self

Creates an empty ValueVec.

pub fn with_capacity(cap: usize) -> Self

Creates with capacity.

pub fn len(&self) -> usize

Current number of elements.

pub fn capacity(&self) -> usize

Current capacity of the backing Vec.

pub fn is_empty(&self) -> bool

Returns true if the vector has no elements.

pub fn reserve(&self, additional: usize)

Ensures capacity for at least additional more elements.

pub fn shrink_to_fit(&self)

Shrinks the capacity as much as possible.

pub fn push(&self, value: V)

Pushes a value (by move) onto the end.

pub fn pop(&self) -> Option<V>

Pops and returns the last element (by move), or None if empty.

pub fn get(&self, index: usize) -> Option<V>

Returns the value of the element at index, if index is in range. Returns None if index is out of bounds. This is a bounds-checked variant of ValueVec::at.

pub fn at(&self, index: usize) -> V

Returns the value at index. Panics if index is out of bounds.

Use ValueVec::get for a bounds-checked version of this method.

pub fn replace(&self, index: usize, value: V) -> V

Moves a value into the slot at index, returning the old value (via move). Panics if index is out of bounds.

pub fn set(&self, index: usize, value: V)

Sets the value of the slot at index to value. Panics if index is out of bounds.

pub fn swap_value(&self, index: usize, value: &mut V)

Swaps the value at index with the provided one in place. Panics if index is out of bounds.

The existing value ends up in *value.

pub fn insert(&self, index: usize, value: V)

Inserts value at position index, shifting elements to the right. Panics if index is out of bounds.

pub fn remove(&self, index: usize) -> V

Removes and returns the element at index, shifting elements left. Panics if index is out of bounds.

pub fn swap_remove(&self, index: usize) -> V

Removes and returns the element at index by swapping in the last element.

O(1) removal when order does not matter.

pub fn contains(&self, value: &V) -> bool
where V: PartialEq,

Returns true if the ValueVec contains an element with the given value.

pub fn clear(&self)

Clears all elements.

pub fn extend<I>(&self, iter: I)
where I: IntoIterator<Item = V>,

Extends the vector by moving in elements from an iterator.

pub fn resize(&self, new_len: usize, value: V)

pub fn resize_with<F>(&self, new_len: usize, f: F)
where F: FnMut() -> V,

pub fn to_vec(&self) -> Vec<V>
where V: Clone,

Returns a snapshot Vec<V> by cloning all elements.

Use From<ValueVec<V>> for Vec<V> for a zero-cost conversion if you don’t want to clone.