AnyProperty

Trait AnyProperty 

pub trait AnyProperty:
    Copy
    + Debug
    + PartialEq
    + Eq
    + Hash
    + 'static { }
Shared trait bounds for property values and canonical values.

These values must be copyable and support equality and deterministic hashing so they can participate in indexing.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors

Source

impl<T> AnyProperty for T
where T: Copy + Debug + PartialEq + Eq + Hash + 'static,