IndexableProperty

Trait IndexableProperty 

pub trait IndexableProperty<E: Entity>:
    Property<E>
    + Eq
    + Hash { }
Marker trait for properties that can be keyed in property indexes.

Property indexes are hash maps keyed by the property value itself, so indexable properties must add Eq and Hash to the general Property requirements.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors

Source

impl<E, P> IndexableProperty<E> for P
where E: Entity, P: Property<E> + Eq + Hash,