PropertyStore

Struct PropertyStore 

pub struct PropertyStore<E: Entity> { /* private fields */ }
A wrapper around a vector of property value stores.

Implementations

Source

impl<E: Entity> PropertyStore<E>

pub fn new() -> Self

Creates a new PropertyStore.

pub fn get<P: Property<E>>(&self) -> &PropertyValueStoreCore<E, P>

Fetches an immutable reference to the PropertyValueStoreCore<E, P>.

pub fn get_mut<P: Property<E>>(&mut self) -> &mut PropertyValueStoreCore<E, P>

Fetches a mutable reference to the PropertyValueStoreCore<E, P>.

pub fn create_value_change_counter<PL, P>(&mut self) -> usize
where PL: PropertyList<E> + Eq + Hash, P: Property<E> + Eq + Hash,

Creates a stratified value change counter for tracked property P with strata PL.

Returns the counter ID.

pub fn get_index_set_for_query_parts( &self, property_id: usize, query_parts: &[&dyn Any], ) -> IndexSetResult<'_, E>

pub fn get_index_count_for_query_parts( &self, property_id: usize, query_parts: &[&dyn Any], ) -> IndexCountResult