Query

Trait Query 

pub trait Query<E: Entity>: QueryInternal<E> { }
Values accepted by user-facing query APIs such as ContextEntitiesExt::query and ContextEntitiesExt::sample_entity.

Use with! to query for specific property values, or pass the entity type directly to work with the entire population.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors

Source

impl<E: Entity> Query<E> for E

Source

impl<E: Entity, QI: QueryInternal<E>> Query<E> for EntityPropertyTuple<E, QI>