pub struct PlanSchedule<P: Eq + PartialEq + Ord> {
pub plan_id: u64,
pub time: f64,
pub priority: P,
}Expand description
A time, id, and priority object used to order plans in the Queue<T>
PlanSchedule objects are sorted in increasing order of time, priority and then
plan id
Fields
plan_id: u64time: f64priority: PTrait Implementations
Sourceimpl<P: Eq + PartialEq + Ord> Ord for PlanSchedule<P>
Entry objects are ordered in increasing order by time, priority, and then
plan id
impl<P: Eq + PartialEq + Ord> Ord for PlanSchedule<P>
Entry objects are ordered in increasing order by time, priority, and then plan id
Sourceimpl<P: Eq + PartialEq + Ord> PartialOrd for PlanSchedule<P>
impl<P: Eq + PartialEq + Ord> PartialOrd for PlanSchedule<P>
impl<P: Eq + PartialEq + Ord + Copy + Clone> Copy for PlanSchedule<P>
impl<P: Eq + PartialEq + Ord> Eq for PlanSchedule<P>
impl<P: Eq + PartialEq + Ord> StructuralPartialEq for PlanSchedule<P>