macro_rules! impl_property_eq {
($name:ident) => { ... };
}Expand description
Implements PartialEq and Eq for a property type
using Ixa’s generated byte-based equality behavior.
This macro is useful when declaring a property type manually and then using
impl_property! or
impl_derived_property!. The type must implement
[rkyv::Archive][crate::rkyv::Archive] and [rkyv::Serialize][crate::rkyv::Serialize], because
equality is computed by serializing the archived representation of each value.
The macro accepts a concrete property type identifier. Generic property types are not supported.