Function run_with_args
Source pub fn run_with_args<F>(setup_fn: F) -> Result<Context, Box<dyn Error>>
Runs a simulation with default cli arguments
This function parses command line arguments allows you to define a setup function
Parameters
setup_fn: A function that takes a mutable reference to a Context and BaseArgs struct
Errors
Returns an error if config loading/merging or the setup function fails.
Invalid command line arguments print an error and exit the process.