pub struct EntityCountTrigger<E: Entity> { /* private fields */ }Expand description
Trigger criterion for the count of entities of a given type.
EntityCountTrigger observes
EntityCreatedEvent for a single entity type and
emits when the total number of entities of that type increases to the configured threshold.
Construction
ⓘ
EntityCountTrigger::<E>::increases_to(threshold)Observation
The observation data passed to
TriggerCriterion::emit_with is
EntityCountTriggerEvent:
ⓘ
pub struct EntityCountTriggerEvent<E: Entity> {
pub entity_id: EntityId<E>,
pub count: usize,
}Semantics
As entities can only be created, not destroyed, the count of entities is monotonic. Thus, this
criterion does not use Direction or TriggerMode.
- It fires when a creation makes the count equal to the threshold.
- The observed count always equals the threshold the trigger was created with.
- If the entity population already equals or exceeds the threshold before the trigger is registered, it will never emit.
- A threshold of
0will not be reached by an entity creation and is therefore not allowed.
Example
use ixa::{Context, ContextEntitiesExt, define_entity, IxaEvent};
use ixa::entity::EntityId;
use ixa::triggers::{ContextTriggersExt, EntityCountTrigger, TriggerCriterion};
define_entity!(Case);
// The event records which case caused us to reach the threshold and
// the value of the threshold itself (as `count`).
#[derive(IxaEvent)]
struct SecondCase {
case_id: EntityId<Case>,
count: usize,
}
let mut context = Context::new();
context.register_trigger(
EntityCountTrigger::increases_to(2)
.emit_with(|observation| SecondCase {
case_id: observation.entity_id,
count: observation.count,
}),
);
context.subscribe_to_event(|_context, _event: SecondCase| {
// respond when the second Case entity is created
});Implementations
Sourceimpl<E: Entity> EntityCountTrigger<E>
impl<E: Entity> EntityCountTrigger<E>
pub fn increases_to(threshold: usize) -> Self