pub struct EntityMap<E: Entity, V> { /* private fields */ }Expand description
A Vec-backed map keyed by EntityId<E>.
Implementations
Sourceimpl<E: Entity, V> EntityMap<E, V>
impl<E: Entity, V> EntityMap<E, V>
Sourcepub fn with_capacity(capacity: usize) -> Self
pub fn with_capacity(capacity: usize) -> Self
Creates an empty EntityMap with space for at least capacity values.
Sourcepub fn into_entity_vec(self) -> EntityVec<E, Option<V>>
pub fn into_entity_vec(self) -> EntityVec<E, Option<V>>
Cheap conversion to an EntityVec<E, Option<V>>
Sourcepub fn reserve(&mut self, additional: usize)
pub fn reserve(&mut self, additional: usize)
Reserves capacity for at least additional more values.
Sourcepub fn shrink_to_fit(&mut self)
pub fn shrink_to_fit(&mut self)
Shrinks the backing vector to fit the highest occupied entity ID.
Sourcepub fn contains_key(&self, entity_id: EntityId<E>) -> bool
pub fn contains_key(&self, entity_id: EntityId<E>) -> bool
Returns true if entity_id is present in the map.
Sourcepub fn get(&self, entity_id: EntityId<E>) -> Option<&V>
pub fn get(&self, entity_id: EntityId<E>) -> Option<&V>
Returns the value for entity_id, or None if not present.
Sourcepub fn get_mut(&mut self, entity_id: EntityId<E>) -> Option<&mut V>
pub fn get_mut(&mut self, entity_id: EntityId<E>) -> Option<&mut V>
Returns the value for entity_id mutably, or None if not present.
Sourcepub fn insert(&mut self, entity_id: EntityId<E>, value: V) -> Option<V>
pub fn insert(&mut self, entity_id: EntityId<E>, value: V) -> Option<V>
Inserts value for entity_id, returning the previous value if one existed.
Sourcepub fn get_or_insert(&mut self, entity_id: EntityId<E>, value: V) -> &mut V
pub fn get_or_insert(&mut self, entity_id: EntityId<E>, value: V) -> &mut V
Returns the value for entity_id, inserting value if it is not already present.
Sourcepub fn get_or_insert_with<F>(&mut self, entity_id: EntityId<E>, f: F) -> &mut Vwhere
F: FnOnce() -> V,
pub fn get_or_insert_with<F>(&mut self, entity_id: EntityId<E>, f: F) -> &mut Vwhere
F: FnOnce() -> V,
Returns the value for entity_id, inserting a value from f if it is not already present.