pub struct EntityVec<E: Entity, V> { /* private fields */ }Expand description
A Vec-backed collection indexed by EntityId<E>.
Implementations
Sourceimpl<E: Entity, V> EntityVec<E, V>
impl<E: Entity, V> EntityVec<E, V>
Sourcepub fn with_capacity(capacity: usize) -> Self
pub fn with_capacity(capacity: usize) -> Self
Creates an empty EntityVec with space for at least capacity items.
Sourcepub fn reserve(&mut self, additional: usize)
pub fn reserve(&mut self, additional: usize)
Reserves capacity for at least additional more values.
Sourcepub fn shrink_to_fit(&mut self)
pub fn shrink_to_fit(&mut self)
Shrinks the backing vector to fit its length.
Sourcepub fn get(&self, entity_id: EntityId<E>) -> Option<&V>
pub fn get(&self, entity_id: EntityId<E>) -> Option<&V>
Returns the value for entity_id, or None if this vector is not long enough.
Sourcepub fn get_mut(&mut self, entity_id: EntityId<E>) -> Option<&mut V>
pub fn get_mut(&mut self, entity_id: EntityId<E>) -> Option<&mut V>
Returns the mutable value for entity_id, or None if this vector is not long enough.
Sourcepub fn as_mut_slice(&mut self) -> &mut [V]
pub fn as_mut_slice(&mut self) -> &mut [V]
Returns the backing slice mutably.
Sourcepub fn iter_mut(&mut self) -> IterMut<'_, V>
pub fn iter_mut(&mut self) -> IterMut<'_, V>
Returns a mutable iterator over the stored values.
Sourcepub fn extend<I>(&mut self, iter: I)where
I: IntoIterator<Item = V>,
pub fn extend<I>(&mut self, iter: I)where
I: IntoIterator<Item = V>,
Extends the vector with values from iter, assigning contiguous IDs to new items.
Sourcepub fn resize(&mut self, new_len: usize, value: V)where
V: Clone,
pub fn resize(&mut self, new_len: usize, value: V)where
V: Clone,
Resizes the vector to new_len, cloning value as needed.
Sourcepub fn resize_with<F>(&mut self, new_len: usize, f: F)where
F: FnMut() -> V,
pub fn resize_with<F>(&mut self, new_len: usize, f: F)where
F: FnMut() -> V,
Resizes the vector to new_len, generating values with f as needed.