pub struct EntityPropertyTuple<E: Entity, T> { /* private fields */ }Expand description
A newtype wrapper that associates a tuple of property values with an entity type.
This is not meant to be used directly, but rather as a backing for the with! macro/ a replacement for the query tuple.
Example
ⓘ
use ixa::{EntityPropertyTuple, define_entity, define_property};
define_entity!(Person);
define_property!(struct Age(u8), Person, default_const = Age(0));
// Use the all macro
let query = with!(Person, Age(42));
// Under the hood this is:
// EntityPropertyTuple::<Person>::new((Age(42),));Implementations