pub fn initialize_global_property_id(global_property_id: &AtomicUsize) -> usizeExpand description
Encapsulates the synchronization logic for initializing a global property’s ID.
Acquires a global lock on the next available global property ID, but only increments it if we successfully initialize the provided ID. The ID of a global property is assigned at runtime but only once per type.