macro_rules! impl_property_hash {
($name:ident) => { ... };
}Expand description
Implements Hash for a property type using Ixa’s generated byte-based
hashing behavior.
This macro is useful when declaring a property type manually and then using
impl_property! or
impl_derived_property!. The type must implement
[rkyv::Archive][crate::rkyv::Archive] and [rkyv::Serialize][crate::rkyv::Serialize], because
hashing is computed by serializing the archived representation into the supplied hasher.
The macro accepts a concrete property type identifier. Generic property types are not supported.