pub trait TriggerSpec: Sized {
// Required method
fn install_in_context(self, context: &mut Context);
}Expand description
A complete installable trigger specification that can be passed to context.register_trigger.
This is automatically implemented by the Trigger types returned by the emit_* methods
on trigger criterion types. Client code should not implement this themselves.
Required Methods
fn install_in_context(self, context: &mut Context)
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.